@@ -62,5 +62,14 @@ class AddProductForm(forms.ModelForm):
             'category',
             'name',
             'stock',
+            'price_retail',
+            'manufacturer',
+            'is_active',
+            'code',
+            'bar_code',
+            'warehouse',
+            'unit_type',
+            'min_stock',
+            'initial_currency',
             'price_retail'
         ]
