@@ -2,20 +2,23 @@
 from datetime import datetime, timedelta
 
 from django.contrib.admin.views.decorators import staff_member_required
-from django.http.response import HttpResponseForbidden, HttpResponseBadRequest
+from django.http.response import (
+    HttpResponseForbidden,
+    HttpResponseBadRequest,
+    JsonResponse
+)
 from django.shortcuts import redirect
+from django.utils.decorators import method_decorator
 from django.utils.translation import ugettext_lazy as _
+from django.views import View
+from django.views.decorators.http import require_POST
 
 from cap.decorators import admin_render_view
-
-from rest_framework.decorators import api_view, APIView
-from rest_framework.response import Response
-
 from invoices import forms
 from invoices.conf import IS_PRODUCT_SELECT_COLLAPSED
 from invoices.models import Sale, Arrival
 
-from apps.products.models import Product
+from products.models import Product
 
 
 @staff_member_required
@@ -45,29 +48,29 @@ def manage_invoice(request, invoice_type, invoice_id):
     }
 
 
-@api_view(['POST'])
+@require_POST
 def update_invoice(request, invoice_type, invoice_id):
 
     invoice = request.invoices.get_invoice(invoice_type, invoice_id)
-    invoice.update(request.data)
+    invoice.update(request.POST)
 
-    return Response({
+    return JsonResponse({
         'message': _('Invoice updated'),
         'total': invoice.serialize_totals()
     })
 
 
-@api_view(['POST'])
+@require_POST
 def add_item(request, invoice_type, invoice_id):
 
     try:
         invoice = request.invoices.get_invoice(invoice_type, invoice_id)
-        product = Product.objects.get(pk=request.data['product'])
+        product = Product.objects.get(pk=request.POST['product'])
         item = invoice.add_item(product)
     except ValueError as e:
         return HttpResponseBadRequest(str(e))
 
-    return Response({
+    return JsonResponse({
         'status': 'OK',
         'html': item.render(),
         'item_id': item.id,
@@ -76,7 +79,8 @@ def add_item(request, invoice_type, invoice_id):
     })
 
 
-class ItemAPI(APIView):
+@method_decorator(staff_member_required, 'dispatch')
+class ItemAPI(View):
 
     def post(self, request, invoice_type, invoice_id, item_id):
 
@@ -85,11 +89,11 @@ class ItemAPI(APIView):
         item = invoice.get_item(item_id)
 
         try:
-            item.update(request.data)
+            item.update(request.POST)
         except ValueError as e:
             return HttpResponseBadRequest(str(e))
 
-        return Response({
+        return JsonResponse({
             'message': _('Item updated'),
             'product': item.serialize_product(),
             'total': invoice.serialize_totals()
@@ -104,7 +108,7 @@ class ItemAPI(APIView):
 
         product = invoice.remove_item(item_id)
 
-        return Response({
+        return JsonResponse({
             'message': _('Item removed'),
             'product': product.serialize(),
             'total': invoice.serialize_totals()
